/*
 * This subclass of Text knows how to create change objects in response
 * to modifications made by the user.
 */

@interface UndoText : Text
{
    NXTextFilterFunc oldTextFilter; /* keep the old text filter around */
    int startBeforeKeydown;	/* beginning of selection before keydown */
    int endBeforeKeydown;	/* end of selection before keydown */
}

/* Creation method */

- initFrame:(const NXRect *)frameRect;

/* Public methods */

- eraseSelection;
- (int)clickCount;
- setClickCount:(int)count;
- keyDown:(NXEvent *)event;
- setTextFilter:(NXTextFilterFunc)aFunc;

/* Methods that create change objects */

- clear:sender;
- cut:sender;
- delete:sender;
- paste:sender;
- setSelGray:(float)value;
- setSelColor:(NXColor)color;
- setSelFont:font;
- subscript:sender;
- superscript:sender;
- underline:sender;
- unscript:sender;
- changeFont:sender;
- changeTabStopAt:(NXCoord)oldX to:(NXCoord)newX;
- setSelProp:(NXParagraphProp)prop to:(NXCoord)val;
- setSelFontSize:(float)size;
- setSelFontFamily:(const char *)fontName;
- replaceSel:(char *)str;
- pasteFont:sender;
- pasteRuler:sender;

@end
